/**
 * Copyright 2007 Steven Van Impe, Department Of Applied Mathematics And Computer Science, Ghent University
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package rkm;

import java.awt.Color;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Locale;
import java.util.ResourceBundle;

import javax.swing.JButton;
import javax.swing.JColorChooser;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;

/**
 * Dialog window that manages the colors used by the geometrical views.
 * 
 * @author Steven Van Impe (steven.vanimpe@ugent.be)
 */
public class RKColorDialog extends JDialog {

	private RKDrawing[] panels;	
	private JButton bgButton, coButton, mPlotButton, sPlotButton, isButton, osButton;
	
	private ResourceBundle bundle = ResourceBundle.getBundle("properties/rkm", Locale.getDefault());
	
	/**
	 * Create a new color dialog.
	 */
	public RKColorDialog(JFrame frame, RKDrawing[] panels) {
		super(frame, ResourceBundle.getBundle("properties/rkm", Locale.getDefault()).getString("colorWindowTitle"));
		this.panels = panels;
		
		setup();
	}
	
	// build gui
	private void setup() {
		setContentPane(new JPanel(new GridBagLayout()));
		
		bgButton = new JButton(bundle.getString("buttonSetColor"));
		bgButton.setBackground(panels[0].getBackground());
		bgButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				Color c = JColorChooser.showDialog(bgButton, bundle.getString("colorBackground"), panels[0].getBackground());
				for (RKDrawing p : panels)
					p.setBackground(c);
				bgButton.setBackground(c);
			}
		});
		
		coButton = new JButton(bundle.getString("buttonSetColor"));
		coButton.setBackground(panels[0].getCoordinateColor());
		coButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				Color c = JColorChooser.showDialog(coButton, bundle.getString("colorCoordinates"), panels[0].getCoordinateColor());
				for (RKDrawing p : panels)
					p.setCoordinateColor(c);
				coButton.setBackground(c);
			}
		});
		
		mPlotButton = new JButton(bundle.getString("buttonSetColor"));
		mPlotButton.setBackground(panels[0].getPlotColor());
		mPlotButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				Color c = JColorChooser.showDialog(mPlotButton, bundle.getString("colorMainPlot"), panels[0].getPlotColor());
				for (RKDrawing p : panels)
					p.setPlotColor(c);
				mPlotButton.setBackground(c);
			}
		});
		
		sPlotButton = new JButton(bundle.getString("buttonSetColor"));
		sPlotButton.setBackground(panels[0].getSecondaryPlotColor());
		sPlotButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				Color c = JColorChooser.showDialog(sPlotButton, bundle.getString("colorSecPlot"), panels[0].getSecondaryPlotColor());
				for (RKDrawing p : panels)
					p.setSecondaryPlotColor(c);
				sPlotButton.setBackground(c);
			}
		});

		isButton = new JButton(bundle.getString("buttonSetColor"));
		isButton.setBackground(panels[0].getInnerStagesColor());
		isButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				Color c = JColorChooser.showDialog(isButton, bundle.getString("colorInnerStages"), panels[0].getInnerStagesColor());
				for (RKDrawing p : panels)
					p.setInnerStagesColor(c);
				isButton.setBackground(c);
			}
		});
		
		osButton = new JButton(bundle.getString("buttonSetColor"));
		osButton.setBackground(panels[0].getOuterStageColor());
		osButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				Color c = JColorChooser.showDialog(osButton, bundle.getString("colorOuterStage"), panels[0].getOuterStageColor());
				for (RKDrawing p : panels)
					p.setOuterStageColor(c);
				osButton.setBackground(c);
			}
		});
		
		
		GridBagConstraints gbc = new GridBagConstraints();
		
		gbc.insets = new Insets(5, 0, 0, 5);
		gbc.weightx = 100;		
		gbc.anchor = GridBagConstraints.WEST;
		
		gbc.gridy = 0;
		gbc.gridx = 0;		
		add(new JLabel(bundle.getString("colorBackground") + ":"), gbc);
		gbc.gridx = 2;
		add(new JLabel(bundle.getString("colorCoordinates") + ":"), gbc);
		
		gbc.gridy = 1;
		gbc.gridx = 0;		
		add(new JLabel(bundle.getString("colorMainPlot") + ":"), gbc);
		gbc.gridx = 2;
		add(new JLabel(bundle.getString("colorSecPlot") + ":"), gbc);
		
		gbc.gridy = 2;
		gbc.gridx = 0;		
		add(new JLabel(bundle.getString("colorInnerStages") + ":"), gbc);
		gbc.gridx = 2;
		add(new JLabel(bundle.getString("colorOuterStage") + ":"), gbc);
		
		gbc.weightx = 0;
		gbc.anchor = GridBagConstraints.CENTER;
		
		gbc.gridx = 1;
		gbc.gridy = 0;
		add(bgButton, gbc);
		gbc.gridy = 1;		
		add(mPlotButton, gbc);
		gbc.gridy = 2;
		add(isButton, gbc);
		
		gbc.insets = new Insets(5, 0, 0, 0);
		
		gbc.gridx = 3;
		gbc.gridy = 0;
		add(coButton, gbc);
		gbc.gridy = 1;
		add(sPlotButton, gbc);
		gbc.gridy = 2;
		add(osButton, gbc);
		
		pack();
	}
}
