/**
 * Copyright 2007 Steven Van Impe, Department Of Applied Mathematics And Computer Science, Ghent University
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package rkm;

import java.awt.BorderLayout;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;
import java.util.Locale;
import java.util.ResourceBundle;

import javax.swing.AbstractAction;
import javax.swing.JComponent;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.KeyStroke;

import rkm.butcher.ForwardEuler;
import rkm.ode.ExampleODE1;

/**
 * Frame for the Runge-Kutta applet.
 * 
 * @author Steven Van Impe (steven.vanimpe@ugent.be)
 */
public class RKFrame extends JFrame {

	private RKModel rkm;
	
	private RKAnimationPanel rkap;
	private RKDerivPanel rkdp;
	private RKMethodDialog rkmd;
	private RKColorDialog rkcd;
	
	/**
	 * Create a new frame.
	 */
	public RKFrame() {
		super(ResourceBundle.getBundle("properties/rkm", Locale.getDefault()).getString("mainWindowTitle"));
		
		rkm = new RKModel(new ExampleODE1(), new ForwardEuler());
		
		rkdp = new RKDerivPanel(rkm);
		rkap = new RKAnimationPanel(rkm, rkdp);
		rkmd = new RKMethodDialog(this, rkm);
		rkcd = new RKColorDialog(this, new RKDrawing[] {rkap, rkdp});
		
		setup();
	}
	
	// build gui
	private void setup() {
		JPanel graphPanel = new JPanel(new GridLayout(1, 2, 5, 0));
		graphPanel.add(rkap);
		graphPanel.add(rkdp);
		
		// catch the C key and launch the color dialog when this key is pressed
		graphPanel.getInputMap(JComponent.WHEN_IN_FOCUSED_WINDOW).put(KeyStroke.getKeyStroke(KeyEvent.VK_C, 0), "Show Dialog");
		graphPanel.getActionMap().put("Show Dialog", new AbstractAction() {
			public void actionPerformed(ActionEvent e) {
		         rkcd.setVisible(true);
		      }
		});
		
		add(graphPanel, BorderLayout.CENTER);
		
		JPanel bottomPanel = new JPanel(new GridBagLayout());
		GridBagConstraints gbc = new GridBagConstraints();
		gbc.fill = GridBagConstraints.BOTH;

		gbc.gridx = 0;
		gbc.gridy = 0;
		gbc.weighty = 80;
		bottomPanel.add(new RKProblemPanel(rkm), gbc);
		gbc.gridy = 1;
		gbc.weighty = 20;
		bottomPanel.add(new RKMethodPanel(rkm, rkmd), gbc);
		
		gbc.gridx = 1;
		gbc.gridy = 0;
		gbc.gridheight = 2;
		gbc.weightx = 100;
		bottomPanel.add(new RKNumPanel(rkm), gbc);
		
		add(bottomPanel, BorderLayout.SOUTH);
		
		pack();
	}
	
	/**
	 * Test program.
	 */
	public static void main(String[] args) {
		RKFrame rkf = new RKFrame();
		rkf.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		rkf.setVisible(true);
	}
}
