/**
 * Copyright 2007 Steven Van Impe, Department Of Applied Mathematics And Computer Science, Ghent University
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package rkm;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.text.MessageFormat;
import java.util.Locale;
import java.util.ResourceBundle;

import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

/**
 * Panel that shows/hides the method dialog and provides information about the method in use.
 * 
 * @author Steven Van Impe (steven.vanimpe@ugent.be)
 */
public class RKMethodPanel extends JPanel implements ChangeListener {

	private RKModel rkm;
	private RKMethodDialog rkmd;
	
	private JLabel methodLabel, stagesLabel;
	
	private ResourceBundle bundle = ResourceBundle.getBundle("properties/rkm", Locale.getDefault());
	
	/**
	 * Create a new method panel.
	 */
	public RKMethodPanel(RKModel rkm, RKMethodDialog rkmd) {
		super(new GridBagLayout());
		this.rkm = rkm;
		rkm.addChangeListener(this);
		this.rkmd = rkmd;
		
		setup();
	}
	
	// build gui
	private void setup() {
		setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(bundle.getString("borderMethod")), BorderFactory.createEmptyBorder(5, 5, 5, 5)));
		
		methodLabel = new JLabel(rkm.getButcherMatrix().toString());
		stagesLabel = new JLabel(MessageFormat.format(bundle.getString("labelTotalStages"), rkm.getButcherMatrix().order()));
		
		JButton setButton = new JButton(bundle.getString("buttonMethod"));
		setButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				rkmd.setVisible(true);
			}
		});
	
		GridBagConstraints gbc = new GridBagConstraints();
		
		gbc.weighty = 100;
		
		gbc.gridx = 0;
		gbc.weightx = 100;
		gbc.anchor = GridBagConstraints.WEST;
		
		gbc.gridy = 0;
		gbc.insets = new Insets(0, 0, 0, 5);
		add(methodLabel, gbc);
		gbc.gridy = 1;
		gbc.insets = new Insets(5, 0, 0, 5);
		add(stagesLabel, gbc);
		
		gbc.gridx = 1;
		gbc.gridy = 0;
		gbc.gridheight = 2;
		gbc.weightx = 0;
		gbc.anchor = GridBagConstraints.EAST;		
		gbc.insets = new Insets(0, 0, 0, 0);
		
		add(setButton, gbc);
	}

	/**
	 * Update the panel to show information about the method in use.
	 */
	public void stateChanged(ChangeEvent e) {
		methodLabel.setText(rkm.getButcherMatrix().toString());
		stagesLabel.setText(MessageFormat.format(bundle.getString("labelTotalStages"), rkm.getButcherMatrix().order()));
	}
}
