/**
 * Copyright 2007 Steven Van Impe, Department Of Applied Mathematics And Computer Science, Ghent University
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package rkm.butcher;

import java.util.Locale;
import java.util.ResourceBundle;

/**
 * Butcher matrix for the 3/8s method.
 * 
 * @author Steven Van Impe (steven.vanimpe@ugent.be)
 */
public class ThreeEights extends ButcherMatrix {

	public ThreeEights() {
		a = new double[][] {{0.0, 0.0, 0.0, 0.0}, {1.0/3.0, 0.0, 0.0, 0.0}, {-1.0/3.0, 1.0, 0.0, 0.0}, {1.0, -1.0, 1.0, 0.0}};
		b = new double[] {1.0/8.0, 3.0/8.0, 3.0/8.0, 1.0/8.0};
		c = new double[] {0.0, 1.0/3.0, 2.0/3.0, 1.0};
	}
	
	public int order() {
		return 4;
	}

	public String toString() {
		return ResourceBundle.getBundle("properties/rkm", Locale.getDefault()).getString("butcher38s");
	}
}
