/**
 * Copyright 2007 Steven Van Impe, Department Of Applied Mathematics And Computer Science, Ghent University
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package rkm.ode;

import java.awt.geom.Point2D;

/**
 * Example ODE: y' = 1 / x.
 * 
 * @author Steven Van Impe (steven.vanimpe@ugent.be)
 */
public class ExampleODE1 extends ODE {

	public boolean requiresParameter() {
		return false;
	}
	
	public double evalDeriv(double x, double y) {
		return 1/x;
	}
	
	public double evalSol(double x0, double y0, double x) {
		return Math.log(x) + y0 - Math.log(x0);
	}
	
	public boolean isNearDiscont(double x0, double y0, double x, double eps) {
		// x has to be strictly positive - in this case at least greater than eps
		return x <= 0 || x < eps;
	}
	
	public boolean isValidInterval(double x0, double y0, double width) {
		// x has to be strictly positive
		return width > 0 && x0 > 0;
	}
	
	public Point2D getStartPointSuggestion() {
		return new Point2D.Double(1, 0);
	}
	
	public double getStepSizeSuggestion() {
		return 3;
	}
	
	public String toString() {
		return "y' = 1 / x";
	}
	
	public String getSolutionDescription() {
		return "y = ln(x) + c";
	}
}
