/**
 * Copyright 2007 Steven Van Impe, Department Of Applied Mathematics And Computer Science, Ghent University
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package rkm.ode;

import java.awt.geom.Point2D;

/**
 * Example ODE: y' = y.
 * 
 * @author Steven Van Impe (steven.vanimpe@ugent.be)
 */
public class ExampleODE2 extends ODE {

	public boolean requiresParameter() {
		return false;
	}
	
	public double evalDeriv(double x, double y) {
		return y;
	}
	
	public double evalSol(double x0, double y0, double x) {
		return Math.exp(x) * y0 / Math.exp(x0);
	}
	
	public boolean isNearDiscont(double x0, double y0, double x, double eps) {
		return false;
	}
	
	public boolean isValidInterval(double x0, double y0, double width) {
		// we don't allow y = 0 for safety reasons, although it is a solution (albeit not a very interesting one)
		return width > 0 && y0 != 0;
	}

	public Point2D getStartPointSuggestion() {
		return new Point2D.Double(2, 2);
	}
	
	public double getStepSizeSuggestion() {
		return 1;
	}
	
	public String toString() {
		return "y' = y";
	}

	public String getSolutionDescription() {
		return "y = ce^x";
	}
}
