/**
 * Copyright 2007 Steven Van Impe, Department Of Applied Mathematics And Computer Science, Ghent University
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package rkm.ode;

import java.awt.geom.Point2D;

/**
 * Example ODE: y' = 1 / 2y.
 * 
 * @author Steven Van Impe (steven.vanimpe@ugent.be)
 */
public class ExampleODE5 extends ODE {

	public boolean requiresParameter() {
		return false;
	}
	
	public double evalDeriv(double x, double y) {
		return 1 / (2 * y);
	}
	
	public double evalSol(double x0, double y0, double x) {
		return (y0 < 0 ? -1 : 1) * Math.sqrt(x + y0 * y0 - x0);
	}
	
	public boolean isNearDiscont(double x0, double y0, double x, double eps) {
		// x has to be greater than -c
		return x + (y0 * y0 - x0) < eps;
	}
	
	public boolean isValidInterval(double x0, double y0, double width) {
		// we don't allow y0 = 0 for safety reasons, although it can be part of a solution
		return width > 0 && y0 != 0;
	}

	public Point2D getStartPointSuggestion() {
		return new Point2D.Double(1, 1);
	}
	
	public double getStepSizeSuggestion() {
		return 3;
	}
	
	public String toString() {
		return "y' = 1 / 2y";
	}
	
	public String getSolutionDescription() {
		return "y = +- sqrt(x + c)";
	}
}
